@@ -46,7 +46,7 @@ class JavaExecutable:
 
     @classmethod
     def get_default_version(cls) -> "JavaExecutable":
-        installs = cls.get_known_java_installations()
+        installs = cls.get_known_java_installations(True)
 
         if len(installs) == 0:
             print(f"{Fore.RED}No registered java versions. Set the default version using"
